﻿/*
 * Licensed under the MIT License
 * 
 * Copyright 2010 (c) Flávio Silva, http://flsilva.com
 *
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 * 
 * http://www.opensource.org/licenses/mit-license.php
 */

package org.as3coreaddendum.display
{
	import flash.display.DisplayObject;
	import flash.geom.Point;
	import flash.text.TextSnapshot;
	
	import org.as3coreaddendum.display.IInteractiveObject;
	
	/**
	 * When working on an architecture of interfaces for user-interface components, this interface may be desirable.
	 * <p>This interface simulates a native <code>DisplayObjectContainer</code> interface, specifying all methods and properties of the <code>DisplayObjectContainer</code> class for pure Flash Player 10.</p>
	 * <p>For more information see the ActionScript 3.0 Language Reference.</p>
	 * 
	 * @author Flávio Silva
	 */
	public interface IDisplayObjectContainer extends IInteractiveObject
	{
		
		function get mouseChildren(): Boolean;
		function set mouseChildren(value:Boolean): void;
		
		function get numChildren(): int;
		
		function get tabChildren(): Boolean;
		function set tabChildren(value:Boolean): void;
		
		function get textSnapshot(): TextSnapshot;
		
		function addChild(child:DisplayObject): DisplayObject;
		
		function addChildAt(child:DisplayObject, index:int): DisplayObject;
		
		function areInaccessibleObjectsUnderPoint(point:Point): Boolean;
		
		function contains(child:DisplayObject): Boolean;
		
		function getChildAt(index:int): DisplayObject;
		
		function getChildByName(name:String): DisplayObject;
		
		function getChildIndex(child:DisplayObject): int;
		
		function getObjectsUnderPoint(point:Point): Array;
		
		function removeChild(child:DisplayObject): DisplayObject;
		
		function removeChildAt(index:int): DisplayObject;
		
		function setChildIndex(child:DisplayObject, index:int): void;
		
		function swapChildren(child1:DisplayObject, child2:DisplayObject): void;
		
		function swapChildrenAt(index1:int, index2:int): void;
		
		
	}

}